@@ -1,9 +1,9 @@
 // Copyright 2019-2022 ChainSafe Systems
 // SPDX-License-Identifier: Apache-2.0, MIT
 
-use actors_runtime::builtin::singletons::SYSTEM_ACTOR_ADDR;
-use actors_runtime::runtime::{ActorCode, Runtime};
-use actors_runtime::{actor_error, wasm_trampoline, ActorError};
+use fil_actors_runtime::builtin::singletons::SYSTEM_ACTOR_ADDR;
+use fil_actors_runtime::runtime::{ActorCode, Runtime};
+use fil_actors_runtime::{actor_error, wasm_trampoline, ActorError};
 use fvm_shared::address::{Address, Protocol};
 use fvm_shared::blockstore::Blockstore;
 use fvm_shared::encoding::RawBytes;
@@ -15,6 +15,9 @@ pub use self::state::State;
 
 mod state;
 
+#[cfg(feature = "wasm")]
+pub const WASM_BINARY: &[u8] = include_bytes!(env!("WASM_BINARY"));
+
 wasm_trampoline!(Actor);
 
 // * Updated to specs-actors commit: 845089a6d2580e46055c24415a6c32ee688e5186 (v3.0.0)
